from collections.abc import Iterable
from typing import Any, ClassVar, Literal, Optional, Sequence, overload

import numpy as np

ALLOW_CHARGE_SEPARATION: ResonanceFlags
ALLOW_INCOMPLETE_OCTETS: ResonanceFlags
AllProps: PropertyPickleOptions
AtomProps: PropertyPickleOptions
BondProps: PropertyPickleOptions
CHI_OTHER: ChiralType
CHI_TETRAHEDRAL_CCW: ChiralType
CHI_TETRAHEDRAL_CW: ChiralType
CHI_UNSPECIFIED: ChiralType
COMPOSITE_AND: CompositeQueryType
COMPOSITE_OR: CompositeQueryType
COMPOSITE_XOR: CompositeQueryType
ComputedProps: PropertyPickleOptions
CoordsAsDouble: PropertyPickleOptions
KEKULE_ALL: ResonanceFlags
MolProps: PropertyPickleOptions
NoConformers: PropertyPickleOptions
NoProps: PropertyPickleOptions
PrivateProps: PropertyPickleOptions
QueryAtomData: PropertyPickleOptions
STEREO_ABSOLUTE: StereoGroupType
STEREO_AND: StereoGroupType
STEREO_OR: StereoGroupType
UNCONSTRAINED_ANIONS: ResonanceFlags
UNCONSTRAINED_CATIONS: ResonanceFlags

class Atom:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def DescribeQuery(cls, RDKit) -> Any: ...
    def GetAtomMapNum(self) -> int: ...
    def GetAtomicNum(self) -> int: ...
    @classmethod
    def GetBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetChiralTag(cls, RDKit) -> Any: ...
    @classmethod
    def GetDegree(cls, RDKit) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetExplicitBitVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetExplicitValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetFormalCharge(cls, RDKit) -> Any: ...
    @classmethod
    def GetHybridization(cls, RDKit) -> Any: ...
    def GetIdx(self) -> int: ...
    @classmethod
    def GetImplicitValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIsAromatic(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsotope(cls, RDKit) -> Any: ...
    @classmethod
    def GetMass(cls, RDKit) -> Any: ...
    @classmethod
    def GetMonomerInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetNeighbors(cls, RDKit) -> Any: ...
    @classmethod
    def GetNoImplicit(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumExplicitHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumImplicitHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumRadicalElectrons(cls, RDKit) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetPDBResidueInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetQueryType(cls, RDKit) -> Any: ...
    def GetSmarts(
        self,
        doKekule: Optional[bool] = False,
        allHsExplicit: Optional[bool] = False,
        isomericSmiles: Optional[bool] = True,
    ) -> str: ...
    @classmethod
    def GetSymbol(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalDegree(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalNumHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasQuery(cls, RDKit) -> Any: ...
    @classmethod
    def InvertChirality(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRing(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRingSize(cls, RDKit, int) -> Any: ...
    @classmethod
    def Match(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NeedsUpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def SetAtomMapNum(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetAtomicNum(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetChiralTag(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetExplicitBitVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetFormalCharge(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetHybridization(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsAromatic(cls, RDKit, bool) -> Any: ...
    def SetIsotope(self, arg1: int) -> None: ...
    @classmethod
    def SetMonomerInfo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetNoImplicit(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetNumExplicitHs(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetNumRadicalElectrons(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetPDBResidueInfo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def __copy__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomKekulizeException(AtomSanitizeException): ...

class AtomMonomerInfo:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetMonomerType(cls, RDKit) -> Any: ...
    @classmethod
    def GetName(cls, RDKit) -> Any: ...
    @classmethod
    def SetMonomerType(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetName(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomMonomerType:
    OTHER: ClassVar[AtomMonomerType] = ...
    PDBRESIDUE: ClassVar[AtomMonomerType] = ...
    UNKNOWN: ClassVar[AtomMonomerType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class AtomPDBResidueInfo(AtomMonomerInfo):
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAltLoc(cls, RDKit) -> Any: ...
    @classmethod
    def GetChainId(cls, RDKit) -> Any: ...
    @classmethod
    def GetInsertionCode(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsHeteroAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetOccupancy(cls, RDKit) -> Any: ...
    @classmethod
    def GetResidueName(cls, RDKit) -> Any: ...
    @classmethod
    def GetResidueNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetSecondaryStructure(cls, RDKit) -> Any: ...
    @classmethod
    def GetSegmentNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetSerialNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetTempFactor(cls, RDKit) -> Any: ...
    @classmethod
    def SetAltLoc(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetChainId(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetInsertionCode(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsHeteroAtom(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetOccupancy(cls, RDKit, double) -> Any: ...
    @classmethod
    def SetResidueName(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetResidueNumber(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetSecondaryStructure(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetSegmentNumber(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetSerialNumber(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetTempFactor(cls, RDKit, double) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomSanitizeException(MolSanitizeException): ...
class AtomValenceException(AtomSanitizeException): ...

class Bond:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def DescribeQuery(cls, RDKit) -> Any: ...
    @classmethod
    def GetBeginAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetBeginAtomIdx(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondDir(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondType(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondTypeAsDouble(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEndAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetEndAtomIdx(cls, RDKit) -> Any: ...
    def GetIdx(self) -> int: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIsAromatic(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsConjugated(cls, RDKit) -> Any: ...
    @classmethod
    def GetOtherAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOtherAtomIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetSmarts(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereo(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereoAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetValenceContrib(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasQuery(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRing(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRingSize(cls, RDKit, int) -> Any: ...
    @classmethod
    def Match(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBondDir(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBondType(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsAromatic(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetIsConjugated(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetStereo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetStereoAtoms(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class BondDir:
    BEGINDASH: ClassVar[BondDir] = ...
    BEGINWEDGE: ClassVar[BondDir] = ...
    EITHERDOUBLE: ClassVar[BondDir] = ...
    ENDDOWNRIGHT: ClassVar[BondDir] = ...
    ENDUPRIGHT: ClassVar[BondDir] = ...
    NONE: ClassVar[BondDir] = ...
    UNKNOWN: ClassVar[BondDir] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class BondStereo:
    STEREOANY: ClassVar[BondStereo] = ...
    STEREOCIS: ClassVar[BondStereo] = ...
    STEREOE: ClassVar[BondStereo] = ...
    STEREONONE: ClassVar[BondStereo] = ...
    STEREOTRANS: ClassVar[BondStereo] = ...
    STEREOZ: ClassVar[BondStereo] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class BondType:
    AROMATIC: ClassVar[BondType] = ...
    DATIVE: ClassVar[BondType] = ...
    DATIVEL: ClassVar[BondType] = ...
    DATIVEONE: ClassVar[BondType] = ...
    DATIVER: ClassVar[BondType] = ...
    DOUBLE: ClassVar[BondType] = ...
    FIVEANDAHALF: ClassVar[BondType] = ...
    FOURANDAHALF: ClassVar[BondType] = ...
    HEXTUPLE: ClassVar[BondType] = ...
    HYDROGEN: ClassVar[BondType] = ...
    IONIC: ClassVar[BondType] = ...
    ONEANDAHALF: ClassVar[BondType] = ...
    OTHER: ClassVar[BondType] = ...
    QUADRUPLE: ClassVar[BondType] = ...
    QUINTUPLE: ClassVar[BondType] = ...
    SINGLE: ClassVar[BondType] = ...
    THREEANDAHALF: ClassVar[BondType] = ...
    THREECENTER: ClassVar[BondType] = ...
    TRIPLE: ClassVar[BondType] = ...
    TWOANDAHALF: ClassVar[BondType] = ...
    UNSPECIFIED: ClassVar[BondType] = ...
    ZERO: ClassVar[BondType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class ChiralType:
    CHI_OTHER: ClassVar[ChiralType] = ...
    CHI_TETRAHEDRAL_CCW: ClassVar[ChiralType] = ...
    CHI_TETRAHEDRAL_CW: ClassVar[ChiralType] = ...
    CHI_UNSPECIFIED: ClassVar[ChiralType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class CompositeQueryType:
    COMPOSITE_AND: ClassVar[CompositeQueryType] = ...
    COMPOSITE_OR: ClassVar[CompositeQueryType] = ...
    COMPOSITE_XOR: ClassVar[CompositeQueryType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class Conformer:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearComputedProps(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomPosition(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetId(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    def GetNumAtoms(self) -> int: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    def GetPositions(
        self,
    ) -> np.ndarray[tuple[int, Literal[3]], np.dtype[np.float64]]: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Is3D(cls, RDKit) -> Any: ...
    @classmethod
    def Set3D(cls, RDKit, bool) -> Any: ...
    @overload
    @classmethod
    def SetAtomPosition(cls, RDKit, unsignedint, boost) -> Any: ...
    @overload
    @classmethod
    def SetAtomPosition(cls, RDKit, unsignedint, RDGeom) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetId(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class EditableMol:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def BeginBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def CommitBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveAtom(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def RemoveBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def RollbackBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class FixedMolSizeMolBundle(MolBundle):
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class HybridizationType:
    OTHER: ClassVar[HybridizationType] = ...
    S: ClassVar[HybridizationType] = ...
    SP: ClassVar[HybridizationType] = ...
    SP2: ClassVar[HybridizationType] = ...
    SP3: ClassVar[HybridizationType] = ...
    SP3D: ClassVar[HybridizationType] = ...
    SP3D2: ClassVar[HybridizationType] = ...
    UNSPECIFIED: ClassVar[HybridizationType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class KekulizeException(MolSanitizeException): ...

class Mol:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddConformer(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ClearComputedProps(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Compute2DCoords(cls, RDKit) -> Any: ...
    @classmethod
    def ComputeGasteigerCharges(cls, RDKit) -> Any: ...
    @classmethod
    def Debug(cls, RDKit) -> Any: ...
    @classmethod
    def GetAromaticAtoms(cls, boost) -> Any: ...
    def GetAtomWithIdx(self, idx: int) -> Atom: ...
    def GetAtoms(self) -> Sequence[Atom]: ...
    def GetAtomsMatchingQuery(self, arg2: QueryAtom) -> Sequence[Atom]: ...
    @classmethod
    def GetBondBetweenAtoms(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBondWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBonds(cls, boost) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    def GetConformer(self, id: int = -1) -> Conformer: ...
    def GetConformers(self) -> Sequence[Conformer]: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    def GetNumAtoms(self, onlyHeavy: int = -1, onlyExplicit: bool = True) -> int: ...
    @classmethod
    def GetNumBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConformers(cls, RDKit) -> Any: ...
    def GetNumHeavyAtoms(self) -> int: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetRingInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereoGroups(cls, RDKit) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NeedsUpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveAllConformers(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveConformer(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @overload
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @overload
    @classmethod
    def ToBinary(cls, RDKit, unsignedint) -> Any: ...
    def UpdatePropertyCache(self, strict=True) -> None: ...
    @classmethod
    def __copy__(cls, boost) -> Any: ...
    @classmethod
    def __deepcopy__(cls) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class MolBundle:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddMol(cls, RDKit, boost) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit, unsignedlong) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Size(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedlong) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class MolSanitizeException(ValueError): ...

class PeriodicTable:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAbundanceForIsotope(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomicNumber(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomicWeight(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetDefaultValence(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetElementSymbol(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetMassForIsotope(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMostCommonIsotope(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetMostCommonIsotopeMass(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetNOuterElecs(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRb0(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRcovalent(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRvdw(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetValenceList(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class PropertyPickleOptions:
    AllProps: ClassVar[PropertyPickleOptions] = ...
    AtomProps: ClassVar[PropertyPickleOptions] = ...
    BondProps: ClassVar[PropertyPickleOptions] = ...
    ComputedProps: ClassVar[PropertyPickleOptions] = ...
    CoordsAsDouble: ClassVar[PropertyPickleOptions] = ...
    MolProps: ClassVar[PropertyPickleOptions] = ...
    NoConformers: ClassVar[PropertyPickleOptions] = ...
    NoProps: ClassVar[PropertyPickleOptions] = ...
    PrivateProps: ClassVar[PropertyPickleOptions] = ...
    QueryAtomData: ClassVar[PropertyPickleOptions] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class QueryAtom(Atom):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ExpandQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class QueryBond(Bond):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ExpandQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RWMol(Mol):
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def BeginBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def CommitBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit) -> Any: ...
    @classmethod
    def InsertMol(cls, *args, **kwargs) -> Any: ...
    def RemoveAtom(self, idx: int) -> None: ...
    @classmethod
    def RemoveBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def RollbackBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def SetStereoGroups(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __copy__(cls, boost) -> Any: ...
    @classmethod
    def __deepcopy__(cls) -> Any: ...
    @classmethod
    def __enter__(cls, RDKit) -> Any: ...
    @classmethod
    def __exit__(cls, type, value, traceback) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class ResonanceFlags:
    ALLOW_CHARGE_SEPARATION: ClassVar[ResonanceFlags] = ...
    ALLOW_INCOMPLETE_OCTETS: ClassVar[ResonanceFlags] = ...
    KEKULE_ALL: ClassVar[ResonanceFlags] = ...
    UNCONSTRAINED_ANIONS: ClassVar[ResonanceFlags] = ...
    UNCONSTRAINED_CATIONS: ClassVar[ResonanceFlags] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class ResonanceMolSupplier:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def Enumerate(cls, RDKit) -> Any: ...
    @classmethod
    def GetAtomConjGrpIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBondConjGrpIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetIsEnumerated(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConjGrps(cls, RDKit) -> Any: ...
    @classmethod
    def GetProgressCallback(cls, RDKit) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetNumThreads(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetProgressCallback(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def WasCanceled(cls, RDKit) -> Any: ...
    @classmethod
    def atEnd(cls, RDKit) -> Any: ...
    @classmethod
    def reset(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, int) -> Any: ...
    @classmethod
    def __iter__(cls, RDKit) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __next__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class ResonanceMolSupplierCallback:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetMaxStructures(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConjGrps(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumDiverseStructures(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetNumStructures(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __call__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RingInfo:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreAtomsInSameRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreAtomsInSameRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreBondsInSameRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreBondsInSameRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreRingFamiliesInitialized(cls, RDKit) -> Any: ...
    @classmethod
    def AtomMembers(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AtomRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def AtomRingSizes(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AtomRings(cls, RDKit) -> Any: ...
    @classmethod
    def BondMembers(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def BondRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def BondRingSizes(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def BondRings(cls, RDKit) -> Any: ...
    @classmethod
    def IsAtomInRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def IsBondInRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def MinAtomRingSize(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def MinBondRingSize(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumAtomRings(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumBondRings(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumRelevantCycles(cls, RDKit) -> Any: ...
    @classmethod
    def NumRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def NumRings(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class StereoDescriptor:
    Bond_Cis: ClassVar[StereoDescriptor] = ...
    Bond_Trans: ClassVar[StereoDescriptor] = ...
    NoValue: ClassVar[StereoDescriptor] = ...
    Tet_CCW: ClassVar[StereoDescriptor] = ...
    Tet_CW: ClassVar[StereoDescriptor] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoGroup:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetGroupType(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class StereoGroupType:
    STEREO_ABSOLUTE: ClassVar[StereoGroupType] = ...
    STEREO_AND: ClassVar[StereoGroupType] = ...
    STEREO_OR: ClassVar[StereoGroupType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoGroup_vect:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class StereoInfo:
    __instance_size__: ClassVar[int] = ...
    centeredOn: Any
    descriptor: Any
    specified: Any
    type: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def NOATOM(self) -> Any: ...
    @property
    def controllingAtoms(self) -> Any: ...

class StereoSpecified:
    Specified: ClassVar[StereoSpecified] = ...
    Unknown: ClassVar[StereoSpecified] = ...
    Unspecified: ClassVar[StereoSpecified] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoType:
    Atom_Tetrahedral: ClassVar[StereoType] = ...
    Bond_Atropisomer: ClassVar[StereoType] = ...
    Bond_Cumulene_Even: ClassVar[StereoType] = ...
    Bond_Double: ClassVar[StereoType] = ...
    Unspecified: ClassVar[StereoType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class SubstanceGroup:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtomWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddAtomWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AddAttachPoint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBondWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddBondWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AddBracket(cls, RDKit, boost) -> Any: ...
    @classmethod
    def AddCState(cls, RDKit, unsignedint, RDGeom) -> Any: ...
    @classmethod
    def AddParentAtomWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddParentAtomWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def ClearAttachPoints(cls, RDKit) -> Any: ...
    @classmethod
    def ClearBrackets(cls, RDKit) -> Any: ...
    @classmethod
    def ClearCStates(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetAttachPoints(cls, RDKit) -> Any: ...
    @classmethod
    def GetBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBrackets(cls, RDKit) -> Any: ...
    @classmethod
    def GetCStates(cls, RDKit) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIndexInMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetParentAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetStringVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetAtoms(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetBonds(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetParentAtoms(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class SubstanceGroupAttach:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def aIdx(self) -> Any: ...
    @property
    def id(self) -> Any: ...
    @property
    def lvIdx(self) -> Any: ...

class SubstanceGroupCState:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def bondIdx(self) -> Any: ...
    @property
    def vector(self) -> Any: ...

class SubstanceGroup_VECT:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class SubstructMatchParameters:
    __instance_size__: ClassVar[int] = ...
    aromaticMatchesConjugated: Any
    maxMatches: Any
    numThreads: Any
    recursionPossible: Any
    uniquify: Any
    useChirality: Any
    useEnhancedStereo: Any
    useGenericMatchers: Any
    useQueryQueryMatches: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def setExtraFinalCheck(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROAtomSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROBondSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROConformerSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROQAtomSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomKekulizeException(_cppMolSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtomIndices(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomSanitizeException(_cppMolSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtomIdx(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomValenceException(_cppAtomSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppMolSanitizeException:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetType(cls, RDKit) -> Any: ...
    @classmethod
    def Message(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _listN5boost10shared_ptrIN5RDKit9ConformerEEE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class _listPN5RDKit4AtomE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class _listPN5RDKit4BondE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

def AddMolSubstanceGroup(*args, **kwargs) -> Any: ...
def ClearMolSubstanceGroups(RDKit) -> Any: ...
def CreateMolSubstanceGroup(*args, **kwargs) -> Any: ...
def CreateStereoGroup(*args, **kwargs) -> Any: ...
def GetAtomAlias(RDKit) -> Any: ...
def GetAtomRLabel(RDKit) -> Any: ...
def GetAtomValue(RDKit) -> Any: ...
def GetDefaultPickleProperties() -> Any: ...
def GetMolSubstanceGroupWithIdx(RDKit, unsignedint) -> Any: ...
def GetMolSubstanceGroups(RDKit) -> Any: ...
def GetPeriodicTable() -> Any: ...
def GetSupplementalSmilesLabel(RDKit) -> Any: ...
def SetAtomAlias(*args, **kwargs) -> Any: ...
def SetAtomRLabel(RDKit, int) -> Any: ...
def SetAtomValue(*args, **kwargs) -> Any: ...
def SetDefaultPickleProperties(unsignedint) -> Any: ...
def SetSupplementalSmilesLabel(*args, **kwargs) -> Any: ...
def _HasSubstructMatchStr(*args, **kwargs) -> Any: ...
def tossit() -> Any: ...



from .utils import memoized_property as memoized_property, pairwise as pairwise
from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem.rdchem import (
    BondDir as BondDir,
    BondStereo as BondStereo,
    BondType as BondType,
)

log: Incomplete

class TautomerTransform:
    BONDMAP: Incomplete
    CHARGEMAP: Incomplete
    name: Incomplete
    tautomer_str: Incomplete
    bonds: Incomplete
    charges: Incomplete
    def __init__(self, name, smarts, bonds=..., charges=..., radicals=...) -> None: ...
    def tautomer(self): ...
    def __repr__(self): ...
    def __str__(self): ...

class TautomerScore:
    name: Incomplete
    smarts_str: Incomplete
    score: Incomplete
    def __init__(self, name, smarts, score) -> None: ...
    def smarts(self): ...
    def __repr__(self): ...
    def __str__(self): ...

TAUTOMER_TRANSFORMS: Incomplete
TAUTOMER_SCORES: Incomplete
MAX_TAUTOMERS: int

class TautomerCanonicalizer:
    transforms: Incomplete
    scores: Incomplete
    max_tautomers: Incomplete
    def __init__(self, transforms=..., scores=..., max_tautomers=...) -> None: ...
    def __call__(self, mol): ...
    def canonicalize(self, mol): ...
    def _enumerate_tautomers(self): ...

class TautomerEnumerator:
    transforms: Incomplete
    max_tautomers: Incomplete
    def __init__(self, transforms=..., max_tautomers=...) -> None: ...
    def __call__(self, mol): ...
    def enumerate(self, mol): ...



from _typeshed import Incomplete
from rdkit.DataStructs.TopNContainer import TopNContainer as TopNContainer

class KNNModel:
    def __init__(self, k, attrs, dfunc, radius: Incomplete | None = ...) -> None: ...
    _examples: Incomplete
    _trainingExamples: Incomplete
    _testExamples: Incomplete
    _k: Incomplete
    _attrs: Incomplete
    _dfunc: Incomplete
    _name: str
    _radius: Incomplete
    def _setup(self, k, attrs, dfunc, radius) -> None: ...
    def GetName(self): ...
    def SetName(self, name) -> None: ...
    def GetExamples(self): ...
    def SetExamples(self, examples) -> None: ...
    def GetTrainingExamples(self): ...
    def SetTrainingExamples(self, examples) -> None: ...
    def GetTestExamples(self): ...
    def SetTestExamples(self, examples) -> None: ...
    def GetNeighbors(self, example): ...



from typing import Any, ClassVar

class AbbreviationDefinition:
    __instance_size__: ClassVar[int] = ...
    displayLabel: Any
    displayLabelW: Any
    label: Any
    mol: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _vectN5RDKit13Abbreviations22AbbreviationDefinitionE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

def CondenseAbbreviationSubstanceGroups(RDKit) -> Any: ...
def CondenseMolAbbreviations(RDKit, boost) -> Any: ...
def GetDefaultAbbreviations() -> Any: ...
def GetDefaultLinkers() -> Any: ...
def LabelMolAbbreviations(RDKit, boost) -> Any: ...
def ParseAbbreviations(*args, **kwargs) -> Any: ...
def ParseLinkers(*args, **kwargs) -> Any: ...



from . import fontinfo as fontinfo, latin1MetricsCache as latin1MetricsCache
from _typeshed import Incomplete

_stdenc_widths: Incomplete
ascent_descent: Incomplete
_Widths: Incomplete

def stringwidth(text, font, encoding): ...



from _typeshed import Incomplete
from rdkit import Chem as Chem, DataStructs as DataStructs, Geometry as Geometry
from rdkit.Chem import Draw as Draw, rdDepictor as rdDepictor
from rdkit.Chem.Draw import rdMolDraw2D as rdMolDraw2D

def _DeleteFpInfoAttr(mol) -> None: ...
def GetAtomicWeightsForFingerprint(refMol, probeMol, fpFunction, metric=...): ...
def GetAtomicWeightsForModel(probeMol, fpFunction, predictionFunction): ...
def GetStandardizedWeights(weights): ...
def GetSimilarityMapFromWeights(
    mol,
    weights,
    colorMap: Incomplete | None = ...,
    scale: int = ...,
    size=...,
    sigma: Incomplete | None = ...,
    coordScale: float = ...,
    step: float = ...,
    colors: str = ...,
    contourLines: int = ...,
    alpha: float = ...,
    draw2d: Incomplete | None = ...,
    **kwargs
): ...
def GetSimilarityMapForFingerprint(
    refMol, probeMol, fpFunction, metric=..., **kwargs
): ...
def GetSimilarityMapForModel(probeMol, fpFunction, predictionFunction, **kwargs): ...

apDict: Incomplete

def GetAPFingerprint(
    mol,
    atomId: int = ...,
    fpType: str = ...,
    nBits: int = ...,
    minLength: int = ...,
    maxLength: int = ...,
    nBitsPerEntry: int = ...,
    **kwargs
): ...

ttDict: Incomplete

def GetTTFingerprint(
    mol,
    atomId: int = ...,
    fpType: str = ...,
    nBits: int = ...,
    targetSize: int = ...,
    nBitsPerEntry: int = ...,
    **kwargs
): ...
def GetMorganFingerprint(
    mol,
    atomId: int = ...,
    radius: int = ...,
    fpType: str = ...,
    nBits: int = ...,
    useFeatures: bool = ...,
    **kwargs
): ...
def GetRDKFingerprint(
    mol,
    atomId: int = ...,
    fpType: str = ...,
    nBits: int = ...,
    minPath: int = ...,
    maxPath: int = ...,
    nBitsPerHash: int = ...,
    **kwargs
): ...



from _typeshed import Incomplete
from rdkit import Chem as Chem

reactionDefs: Incomplete
reactions: Incomplete

class RecapHierarchyNode:
    mol: Incomplete
    children: Incomplete
    parents: Incomplete
    smiles: Incomplete
    def __init__(self, mol) -> None: ...
    def GetAllChildren(self): ...
    def GetLeaves(self): ...
    def getUltimateParents(self): ...
    def _gacRecurse(self, res, terminalOnly: bool = ...) -> None: ...
    def __del__(self) -> None: ...

def RecapDecompose(
    mol,
    allNodes: Incomplete | None = ...,
    minFragmentSize: int = ...,
    onlyUseReactions: Incomplete | None = ...,
): ...



from _typeshed import Incomplete
from rdkit import RDRandom as RDRandom

SeqTypes: Incomplete

def SplitIndices(
    nPts, frac, silent: int = ..., legacy: int = ..., replacement: int = ...
): ...
def SplitDataSet(data, frac, silent: int = ...): ...
def SplitDbData(
    conn,
    fracs,
    table: str = ...,
    fields: str = ...,
    where: str = ...,
    join: str = ...,
    labelCol: str = ...,
    useActs: int = ...,
    nActs: int = ...,
    actCol: str = ...,
    actBounds=...,
    silent: int = ...,
): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from rdkit.DataStructs.VectCollection import VectCollection as VectCollection
from rdkit.ML.DecTree import DecTree as DecTree

class SigTreeNode(DecTree.DecTreeNode):
    def NameModel(self, *args, **kwargs) -> None: ...
    def ClassifyExample(self, example, appendExamples: int = ...): ...
    def __init__(self, *args, **kwargs) -> None: ...



from typing import Any

def GetUFFAngleBendParams(*args, **kwargs) -> Any: ...
def GetUFFBondStretchParams(*args, **kwargs) -> Any: ...
def GetUFFInversionParams(*args, **kwargs) -> Any: ...
def GetUFFTorsionParams(*args, **kwargs) -> Any: ...
def GetUFFVdWParams(*args, **kwargs) -> Any: ...
def MMFFGetMoleculeForceField(RDKit, ForceFields) -> Any: ...
def MMFFGetMoleculeProperties(RDKit) -> Any: ...
def MMFFHasAllMoleculeParams(RDKit) -> Any: ...
def MMFFOptimizeMolecule(RDKit) -> Any: ...
def MMFFOptimizeMoleculeConfs(RDKit) -> Any: ...
def MMFFSanitizeMolecule(RDKit) -> Any: ...
def OptimizeMolecule(ForceFields) -> Any: ...
def OptimizeMoleculeConfs(RDKit, ForceFields) -> Any: ...
def UFFGetMoleculeForceField(RDKit) -> Any: ...
def UFFHasAllMoleculeParams(RDKit) -> Any: ...
def UFFOptimizeMolecule(RDKit) -> Any: ...
def UFFOptimizeMoleculeConfs(RDKit) -> Any: ...



from .errors import StopValidateError as StopValidateError
from .fragment import REMOVE_FRAGMENTS as REMOVE_FRAGMENTS
from _typeshed import Incomplete
from rdkit import Chem as Chem

class Validation:
    log: Incomplete
    def __init__(self, log) -> None: ...
    def __call__(self, mol) -> None: ...
    def run(self, mol) -> None: ...

class SmartsValidation(Validation):
    level: Incomplete
    message: str
    entire_fragment: bool
    _smarts: Incomplete
    def __init__(self, log) -> None: ...
    @property
    def smarts(self) -> str: ...
    def _check_matches(self, mol) -> None: ...
    def _check_matches_fragment(self, mol) -> None: ...
    def run(self, mol) -> None: ...

class IsNoneValidation(Validation):
    def run(self, mol) -> None: ...

class NoAtomValidation(Validation):
    def run(self, mol) -> None: ...

class DichloroethaneValidation(SmartsValidation):
    level: Incomplete
    smarts: str
    entire_fragment: bool
    message: str

class FragmentValidation(Validation):
    fragments: Incomplete
    def run(self, mol) -> None: ...

class NeutralValidation(Validation):
    def run(self, mol) -> None: ...

class IsotopeValidation(Validation):
    def run(self, mol) -> None: ...

VALIDATIONS: Incomplete



from _typeshed import Incomplete

class TreeNode:
    children: Incomplete
    parent: Incomplete
    name: Incomplete
    data: Incomplete
    terminalNode: Incomplete
    label: Incomplete
    level: Incomplete
    examples: Incomplete
    def __init__(
        self,
        parent,
        name,
        label: Incomplete | None = ...,
        data: Incomplete | None = ...,
        level: int = ...,
        isTerminal: int = ...,
    ) -> None: ...
    def NameTree(self, varNames) -> None: ...
    NameModel: Incomplete
    def AddChildNode(self, node) -> None: ...
    def AddChild(
        self,
        name,
        label: Incomplete | None = ...,
        data: Incomplete | None = ...,
        isTerminal: int = ...,
    ): ...
    def PruneChild(self, child) -> None: ...
    def ReplaceChildIndex(self, index, newChild) -> None: ...
    def GetChildren(self): ...
    def Destroy(self) -> None: ...
    def GetName(self): ...
    def SetName(self, name) -> None: ...
    def GetData(self): ...
    def SetData(self, data) -> None: ...
    def GetTerminal(self): ...
    def SetTerminal(self, isTerminal) -> None: ...
    def GetLabel(self): ...
    def SetLabel(self, label) -> None: ...
    def GetLevel(self): ...
    def SetLevel(self, level) -> None: ...
    def GetParent(self): ...
    def SetParent(self, parent) -> None: ...
    def Print(self, level: int = ..., showData: int = ...) -> None: ...
    def Pickle(self, fileName: str = ...) -> None: ...
    def __str__(self): ...
    def __cmp__(self, other): ...
    def __lt__(self, other): ...
    def __eq__(self, other): ...

def _exampleCode() -> None: ...



from rdkit.VLib.NodeLib import *
from _typeshed import Incomplete
from rdkit import Chem as Chem, RDConfig as RDConfig
from rdkit.VLib import Filter as Filter, Supply as Supply

smis: Incomplete
mols: Incomplete
supplier: Incomplete
metals: str
smaFilter: Incomplete
salts: Incomplete
remover: Incomplete
atsFilter: Incomplete
dupeFilter: Incomplete
io: Incomplete
output: Incomplete



from typing import Any, ClassVar, Sequence, overload

from rdkit.Chem.rdchem import Mol
from rdkit.Chem.rdMolDescriptors import AtomPairsParameters
from rdkit.DataStructs.cDataStructs import ExplicitBitVect

ADJUST_IGNOREALL: AdjustQueryWhichFlags
ADJUST_IGNORECHAINS: AdjustQueryWhichFlags
ADJUST_IGNOREDUMMIES: AdjustQueryWhichFlags
ADJUST_IGNORENONDUMMIES: AdjustQueryWhichFlags
ADJUST_IGNORENONE: AdjustQueryWhichFlags
ADJUST_IGNORERINGS: AdjustQueryWhichFlags
AROMATICITY_CUSTOM: AromaticityModel
AROMATICITY_DEFAULT: AromaticityModel
AROMATICITY_MDL: AromaticityModel
AROMATICITY_RDKIT: AromaticityModel
AROMATICITY_SIMPLE: AromaticityModel
LayeredFingerprint_substructLayers: int
SANITIZE_ADJUSTHS: SanitizeFlags
SANITIZE_ALL: SanitizeFlags
SANITIZE_CLEANUP: SanitizeFlags
SANITIZE_CLEANUPCHIRALITY: SanitizeFlags
SANITIZE_FINDRADICALS: SanitizeFlags
SANITIZE_KEKULIZE: SanitizeFlags
SANITIZE_NONE: SanitizeFlags
SANITIZE_PROPERTIES: SanitizeFlags
SANITIZE_SETAROMATICITY: SanitizeFlags
SANITIZE_SETCONJUGATION: SanitizeFlags
SANITIZE_SETHYBRIDIZATION: SanitizeFlags
SANITIZE_SYMMRINGS: SanitizeFlags
_LayeredFingerprint_version: str
_PatternFingerprint_version: str
_RDKFingerprint_version: str

class AdjustQueryParameters:
    __instance_size__: ClassVar[int] = ...
    adjustConjugatedFiveRings: Any
    adjustDegree: Any
    adjustDegreeFlags: Any
    adjustHeavyDegree: Any
    adjustHeavyDegreeFlags: Any
    adjustRingChain: Any
    adjustRingChainFlags: Any
    adjustRingCount: Any
    adjustRingCountFlags: Any
    adjustSingleBondsBetweenAromaticAtoms: Any
    adjustSingleBondsToDegreeOneNeighbors: Any
    aromatizeIfPossible: Any
    makeAtomsGeneric: Any
    makeAtomsGenericFlags: Any
    makeBondsGeneric: Any
    makeBondsGenericFlags: Any
    makeDummiesQueries: Any
    setMDLFiveRingAromaticity: Any
    useStereoCareForBonds: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def NoAdjustments(self, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AdjustQueryWhichFlags:
    ADJUST_IGNOREALL: ClassVar[AdjustQueryWhichFlags] = ...
    ADJUST_IGNORECHAINS: ClassVar[AdjustQueryWhichFlags] = ...
    ADJUST_IGNOREDUMMIES: ClassVar[AdjustQueryWhichFlags] = ...
    ADJUST_IGNORENONDUMMIES: ClassVar[AdjustQueryWhichFlags] = ...
    ADJUST_IGNORENONE: ClassVar[AdjustQueryWhichFlags] = ...
    ADJUST_IGNORERINGS: ClassVar[AdjustQueryWhichFlags] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class AromaticityModel:
    AROMATICITY_CUSTOM: ClassVar[AromaticityModel] = ...
    AROMATICITY_DEFAULT: ClassVar[AromaticityModel] = ...
    AROMATICITY_MDL: ClassVar[AromaticityModel] = ...
    AROMATICITY_RDKIT: ClassVar[AromaticityModel] = ...
    AROMATICITY_SIMPLE: ClassVar[AromaticityModel] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class MolzipLabel:
    AtomMapNumber: ClassVar[MolzipLabel] = ...
    AtomType: ClassVar[MolzipLabel] = ...
    FragmentOnBonds: ClassVar[MolzipLabel] = ...
    Isotope: ClassVar[MolzipLabel] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class MolzipParams:
    __instance_size__: ClassVar[int] = ...
    enforceValenceRules: Any
    label: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def setAtomSymbols(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RemoveHsParameters:
    __instance_size__: ClassVar[int] = ...
    removeAndTrackIsotopes: Any
    removeDefiningBondStereo: Any
    removeDegreeZero: Any
    removeDummyNeighbors: Any
    removeHigherDegrees: Any
    removeHydrides: Any
    removeInSGroups: Any
    removeIsotopes: Any
    removeMapped: Any
    removeNonimplicit: Any
    removeOnlyHNeighbors: Any
    removeWithQuery: Any
    removeWithWedgedBond: Any
    showWarnings: Any
    updateExplicitCount: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class SanitizeFlags:
    SANITIZE_ADJUSTHS: ClassVar[SanitizeFlags] = ...
    SANITIZE_ALL: ClassVar[SanitizeFlags] = ...
    SANITIZE_CLEANUP: ClassVar[SanitizeFlags] = ...
    SANITIZE_CLEANUPCHIRALITY: ClassVar[SanitizeFlags] = ...
    SANITIZE_FINDRADICALS: ClassVar[SanitizeFlags] = ...
    SANITIZE_KEKULIZE: ClassVar[SanitizeFlags] = ...
    SANITIZE_NONE: ClassVar[SanitizeFlags] = ...
    SANITIZE_PROPERTIES: ClassVar[SanitizeFlags] = ...
    SANITIZE_SETAROMATICITY: ClassVar[SanitizeFlags] = ...
    SANITIZE_SETCONJUGATION: ClassVar[SanitizeFlags] = ...
    SANITIZE_SETHYBRIDIZATION: ClassVar[SanitizeFlags] = ...
    SANITIZE_SYMMRINGS: ClassVar[SanitizeFlags] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoBondThresholds:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def CHIRAL_ATOM(self) -> Any: ...
    @property
    def DBL_BOND_NO_STEREO(self) -> Any: ...
    @property
    def DBL_BOND_SPECIFIED_STEREO(self) -> Any: ...
    @property
    def DIRECTION_SET(self) -> Any: ...

class _vectN5RDKit9Chirality10StereoInfoE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

def AddHs(
    mol: Mol,
    explicitOnly: bool = False,
    addCoords: bool = False,
    onlyOnAtoms: AtomPairsParameters | None = None,
    addResidueInfo: bool = False,
) -> Mol: ...
def AddRecursiveQuery(*args, **kwargs) -> Any: ...
def AddWavyBondsForStereoAny(RDKit) -> Any: ...
def AdjustQueryProperties(RDKit) -> Any: ...
def AssignAtomChiralTagsFromMolParity(RDKit) -> Any: ...
def AssignAtomChiralTagsFromStructure(RDKit) -> Any: ...
def AssignChiralTypesFromBondDirs(RDKit) -> Any: ...
def AssignRadicals(RDKit) -> Any: ...
def AssignStereochemistry(*args, **kwargs) -> Any: ...
def AssignStereochemistryFrom3D(*args, **kwargs) -> Any: ...
def Cleanup(RDKit) -> Any: ...
def CombineMols(*args, **kwargs) -> Any: ...
def ConvertGenericQueriesToSubstanceGroups(RDKit) -> Any: ...
def DeleteSubstructs(*args, **kwargs) -> Any: ...
def DetectBondStereoChemistry(*args, **kwargs) -> Any: ...
def DetectBondStereochemistry(RDKit) -> Any: ...
def DetectChemistryProblems(RDKit) -> Any: ...
def FastFindRings(RDKit) -> Any: ...
def FindAllPathsOfLengthN(*args, **kwargs) -> Any: ...
def FindAllSubgraphsOfLengthMToN(*args, **kwargs) -> Any: ...
def FindAllSubgraphsOfLengthN(*args, **kwargs) -> Any: ...
def FindAtomEnvironmentOfRadiusN(*args, **kwargs) -> Any: ...
def FindPotentialStereo(RDKit) -> Any: ...
def FindPotentialStereoBonds(*args, **kwargs) -> Any: ...
def FindRingFamilies(RDKit) -> Any: ...
def FindUniqueSubgraphsOfLengthN(*args, **kwargs) -> Any: ...
def FragmentOnBRICSBonds(RDKit) -> Any: ...
def FragmentOnBonds(RDKit, boost) -> Any: ...
def FragmentOnSomeBonds(RDKit, boost) -> Any: ...
def Get3DDistanceMatrix(RDKit) -> Any: ...
def GetAdjacencyMatrix(RDKit) -> Any: ...
def GetDistanceMatrix(RDKit) -> Any: ...
def GetFormalCharge(RDKit) -> Any: ...
def GetMolFrags(
    mol: Mol,
    asMols: bool = False,
    sanitizeFrags: bool = True,
    frags: Sequence[int] | None = None,
    fragsMolAtomMapping: Sequence[Sequence[int]] | None = None,
) -> tuple[Mol] | tuple[tuple[int]]: ...
def GetMostSubstitutedCoreMatch(*args, **kwargs) -> Any: ...
def GetSSSR(RDKit) -> Any: ...
def GetShortestPath(*args, **kwargs) -> Any: ...
def GetSymmSSSR(RDKit) -> Any: ...
def Kekulize(RDKit) -> Any: ...
def KekulizeIfPossible(RDKit) -> Any: ...
def LayeredFingerprint(
    mol: Mol,
    layerFlags: int = 4294967295,
    minPath: int = 1,
    maxPath: int = 7,
    fpSize: int = 2048,
    atomCounts: list[int] = [],
    setOnlyBits: ExplicitBitVect | None = None,
    branchedPaths: bool = True,
    fromAtoms: Sequence[int] | None = None,
) -> ExplicitBitVect: ...
def MergeQueryHs(RDKit) -> Any: ...
def MolAddRecursiveQueries(*args, **kwargs) -> Any: ...
def MurckoDecompose(RDKit) -> Any: ...
def ParseMolQueryDefFile(boost) -> Any: ...
def PathToSubmol(RDKit, boost) -> Any: ...
def PatternFingerprint(RDKit) -> Any: ...
def RDKFingerprint(*args, **kwargs) -> Any: ...
def RemoveAllHs(RDKit) -> Any: ...
@overload
def RemoveHs(
    mol: Mol,
    implicitOnly: bool = False,
    updateExplicitCount: bool = False,
    sanitize: bool = True,
) -> Mol: ...
@overload
def RemoveHs(
    mol: Mol,
    params: RemoveHsParameters,
    sanitize: bool = True,
) -> Mol: ...
def RemoveStereochemistry(RDKit) -> Any: ...
def RenumberAtoms(RDKit, boost) -> Any: ...
def ReplaceCore(mol, core, match) -> Any: ...
def ReplaceSidechains(*args, **kwargs) -> Any: ...
def ReplaceSubstructs(*args, **kwargs) -> Any: ...
def SanitizeMol(*args, **kwargs) -> Any: ...
def SetAromaticity(RDKit) -> Any: ...
def SetBondStereoFromDirections(RDKit) -> Any: ...
def SetConjugation(RDKit) -> Any: ...
def SetDoubleBondNeighborDirections(RDKit) -> Any: ...
def SetGenericQueriesFromProperties(RDKit) -> Any: ...
def SetHybridization(RDKit) -> Any: ...
def SetTerminalAtomCoords(*args, **kwargs) -> Any: ...
def SortMatchesByDegreeOfCoreSubstitution(*args, **kwargs) -> Any: ...
def SplitMolByPDBChainId(RDKit) -> Any: ...
def SplitMolByPDBResidues(RDKit) -> Any: ...
def UnfoldedRDKFingerprintCountBased(RDKit) -> Any: ...
def WedgeBond(*args, **kwargs) -> Any: ...
def WedgeMolBonds(*args, **kwargs) -> Any: ...
def molzip(RDKit) -> Any: ...



from _typeshed import Incomplete
from rdkit.Chem import ChemicalFeatures as ChemicalFeatures

class FeatMapPoint(ChemicalFeatures.FreeChemicalFeature):
    weight: float
    featDirs: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def initFromFeat(self, feat) -> None: ...
    def GetDist2(self, other): ...
    def GetDirMatch(self, other, useBest: bool = ...): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig
from rdkit.VLib.Supply import SupplyNode as SupplyNode

class _lazyDataSeq:
    cursor: Incomplete
    cmd: Incomplete
    _first: int
    _pickleCol: Incomplete
    _depickle: Incomplete
    _klass: Incomplete
    def __init__(
        self,
        cursor,
        cmd,
        pickleCol: int = ...,
        depickle: int = ...,
        klass: Incomplete | None = ...,
    ) -> None: ...
    def _validate(self) -> None: ...
    def __iter__(self): ...
    def next(self): ...

class _dataSeq(_lazyDataSeq):
    cursor: Incomplete
    cmd: Incomplete
    res: Incomplete
    rowCount: int
    idx: int
    _pickleCol: Incomplete
    _depickle: Incomplete
    def __init__(
        self, cursor, cmd, pickleCol: int = ..., depickle: int = ...
    ) -> None: ...
    _first: Incomplete
    def __iter__(self): ...
    def next(self): ...
    def __len__(self) -> int: ...
    def __getitem__(self, idx): ...

class DbPickleSupplyNode(SupplyNode):
    _dbResults: Incomplete
    _supplier: Incomplete
    def __init__(self, cursor, cmd, binaryCol, **kwargs) -> None: ...
    def reset(self) -> None: ...
    def next(self): ...

def GetNode(dbName, tableName): ...
def _test(): ...



from _typeshed import Incomplete
from rdkit import Geometry as Geometry
from rdkit.Chem.FeatMaps import FeatMapPoint as FeatMapPoint, FeatMaps as FeatMaps

class FeatMapParseError(ValueError): ...

class FeatMapParser:
    data: Incomplete
    _lineNum: int
    def __init__(
        self, file: Incomplete | None = ..., data: Incomplete | None = ...
    ) -> None: ...
    def SetData(self, data) -> None: ...
    def _NextLine(self): ...
    def Parse(self, featMap: Incomplete | None = ...): ...
    def ParseParamBlock(self): ...
    def _parsePoint(self, txt): ...
    def ParseFeatPointBlock(self): ...



from _typeshed import Incomplete

class TopNContainer:
    _size: Incomplete
    best: Incomplete
    extras: Incomplete
    def __init__(self, size, mostNeg=...) -> None: ...
    def Insert(self, val, extra: Incomplete | None = ...) -> None: ...
    def GetPts(self): ...
    def GetExtras(self): ...
    def __len__(self) -> int: ...
    def __getitem__(self, which): ...
    def reverse(self) -> None: ...

def _exampleCode() -> None: ...



from _typeshed import Incomplete
from rdkit.Chem.Draw.canvasbase import CanvasBase as CanvasBase

class Canvas(CanvasBase):
    size: Incomplete
    qsize: Incomplete
    pixmap: Incomplete
    painter: Incomplete
    def __init__(self, size) -> None: ...
    def addCanvasLine(
        self, p1, p2, color=..., color2: Incomplete | None = ..., **kwargs
    ) -> None: ...
    def addCanvasText(self, text, pos, font, color=..., **kwargs): ...
    def addCanvasPolygon(
        self, ps, color=..., fill: bool = ..., stroke: bool = ..., **kwargs
    ) -> None: ...
    def addCanvasDashedWedge(
        self, p1, p2, p3, dash=..., color=..., color2: Incomplete | None = ..., **kwargs
    ) -> None: ...
    def flush(self) -> None: ...



from typing import Any, ClassVar

AtomIndexLabels: RGroupLabels
AtomMap: RGroupLabelling
AtomMapLabels: RGroupLabels
AutoDetect: RGroupLabels
DummyAtomLabels: RGroupLabels
Exhaustive: RGroupMatching
FingerprintVariance: RGroupScore
GA: RGroupMatching
Greedy: RGroupMatching
GreedyChunks: RGroupMatching
Isotope: RGroupLabelling
IsotopeLabels: RGroupLabels
MCS: RGroupCoreAlignment
MDLRGroup: RGroupLabelling
MDLRGroupLabels: RGroupLabels
Match: RGroupScore
NoAlignment: RGroupCoreAlignment
NoSymmetrization: RGroupMatching
# None: RGroupCoreAlignment
RelabelDuplicateLabels: RGroupLabels

class RGroupCoreAlignment:
    MCS: ClassVar[RGroupCoreAlignment] = ...
    NoAlignment: ClassVar[RGroupCoreAlignment] = ...
    # None: ClassVar[RGroupCoreAlignment] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class RGroupDecomposition:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def Add(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetRGroupLabels(cls, RDKit) -> Any: ...
    @classmethod
    def GetRGroupsAsColumns(cls, RDKit) -> Any: ...
    @classmethod
    def GetRGroupsAsRows(cls, RDKit) -> Any: ...
    @classmethod
    def Process(cls, RDKit) -> Any: ...
    @classmethod
    def ProcessAndScore(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RGroupDecompositionParameters:
    __instance_size__: ClassVar[int] = ...
    alignment: Any
    allowNonTerminalRGroups: Any
    chunkSize: Any
    gaMaximumOperations: Any
    gaNumberOperationsWithoutImprovement: Any
    gaNumberRuns: Any
    gaParallelRuns: Any
    gaPopulationSize: Any
    gaRandomSeed: Any
    labels: Any
    matchingStrategy: Any
    onlyMatchAtRGroups: Any
    removeAllHydrogenRGroups: Any
    removeAllHydrogenRGroupsAndLabels: Any
    removeHydrogensPostMatch: Any
    rgroupLabelling: Any
    scoreMethod: Any
    timeout: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def substructMatchParams(self) -> Any: ...

class RGroupLabelling:
    AtomMap: ClassVar[RGroupLabelling] = ...
    Isotope: ClassVar[RGroupLabelling] = ...
    MDLRGroup: ClassVar[RGroupLabelling] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class RGroupLabels:
    AtomIndexLabels: ClassVar[RGroupLabels] = ...
    AtomMapLabels: ClassVar[RGroupLabels] = ...
    AutoDetect: ClassVar[RGroupLabels] = ...
    DummyAtomLabels: ClassVar[RGroupLabels] = ...
    IsotopeLabels: ClassVar[RGroupLabels] = ...
    MDLRGroupLabels: ClassVar[RGroupLabels] = ...
    RelabelDuplicateLabels: ClassVar[RGroupLabels] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class RGroupMatching:
    Exhaustive: ClassVar[RGroupMatching] = ...
    GA: ClassVar[RGroupMatching] = ...
    Greedy: ClassVar[RGroupMatching] = ...
    GreedyChunks: ClassVar[RGroupMatching] = ...
    NoSymmetrization: ClassVar[RGroupMatching] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class RGroupScore:
    FingerprintVariance: ClassVar[RGroupScore] = ...
    Match: ClassVar[RGroupScore] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

def RGroupDecompose(*args, **kwargs) -> Any: ...



from typing import Any, ClassVar

from typing import overload

EIGHTBITVALUE: DiscreteValueType
FOURBITVALUE: DiscreteValueType
ONEBITVALUE: DiscreteValueType
SIXTEENBITVALUE: DiscreteValueType
TWOBITVALUE: DiscreteValueType

class DiscreteValueType:
    EIGHTBITVALUE: ClassVar[DiscreteValueType] = ...
    FOURBITVALUE: ClassVar[DiscreteValueType] = ...
    ONEBITVALUE: ClassVar[DiscreteValueType] = ...
    SIXTEENBITVALUE: ClassVar[DiscreteValueType] = ...
    TWOBITVALUE: ClassVar[DiscreteValueType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class DiscreteValueVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetTotalVal(cls, RDKit) -> Any: ...
    @classmethod
    def GetValueType(cls, RDKit) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __iadd__(cls, boost, RDKit) -> Any: ...
    @classmethod
    def __isub__(cls, boost, RDKit) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...
    @classmethod
    def __sub__(cls, other) -> Any: ...

class ExplicitBitVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def FromBase64(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumOffBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumOnBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOnBits(cls, ExplicitBitVect) -> Any: ...
    @classmethod
    def SetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBitsFromList(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToBase64(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToBinary(cls, ExplicitBitVect) -> Any: ...
    @classmethod
    def ToBitString(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToList(cls, ExplicitBitVect) -> Any: ...
    @classmethod
    def UnSetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UnSetBitsFromList(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, ExplicitBitVect) -> Any: ...
    @classmethod
    def __getitem__(cls, ExplicitBitVect, int) -> Any: ...
    @classmethod
    def __iadd__(cls, boost, ExplicitBitVect) -> Any: ...
    @classmethod
    def __invert__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...
    @classmethod
    def __xor__(cls, other) -> Any: ...

class FPBReader:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetBytes(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetContainingNeighbors(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetFP(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetId(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetNumBits(cls, RDKit) -> Any: ...
    @classmethod
    def GetTanimoto(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetTanimotoNeighbors(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetTversky(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetTverskyNeighbors(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Init(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class IntSparseIntVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetLength(cls, RDKit) -> Any: ...
    @classmethod
    def GetNonzeroElements(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalVal(cls, RDKit) -> Any: ...
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @classmethod
    def ToList(cls, RDKit) -> Any: ...
    @classmethod
    def UpdateFromSequence(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, int) -> Any: ...
    def __iadd__(self, RDKit) -> Any: ...
    @classmethod
    def __idiv__(cls, boost, int) -> Any: ...
    @classmethod
    def __imul__(cls, boost, int) -> Any: ...
    def __isub__(self, RDKit) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...
    @classmethod
    def __sub__(cls, other) -> Any: ...

class LongSparseIntVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetLength(cls, RDKit) -> Any: ...
    @classmethod
    def GetNonzeroElements(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalVal(cls, RDKit) -> Any: ...
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @classmethod
    def ToList(cls, RDKit) -> Any: ...
    @classmethod
    def UpdateFromSequence(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, long) -> Any: ...
    def __iadd__(self, RDKit) -> Any: ...
    @classmethod
    def __idiv__(cls, boost, int) -> Any: ...
    @classmethod
    def __imul__(cls, boost, int) -> Any: ...
    def __isub__(self, RDKit) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, RDKit, long, int) -> Any: ...
    @classmethod
    def __sub__(cls, other) -> Any: ...

class MultiFPBReader:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddReader(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetContainingNeighbors(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumBits(cls, RDKit) -> Any: ...
    @classmethod
    def GetReader(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetTanimotoNeighbors(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetTverskyNeighbors(cls, *args, **kwargs) -> Any: ...
    @overload
    @classmethod
    def Init(cls) -> Any: ...
    @overload
    @classmethod
    def Init(cls, RDKit) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class SparseBitVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def FromBase64(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumOffBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumOnBits(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOnBits(cls, SparseBitVect) -> Any: ...
    @classmethod
    def SetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBitsFromList(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToBase64(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToBinary(cls, SparseBitVect) -> Any: ...
    @classmethod
    def ToBitString(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ToList(cls, SparseBitVect) -> Any: ...
    @classmethod
    def UnSetBit(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UnSetBitsFromList(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, SparseBitVect) -> Any: ...
    @classmethod
    def __getitem__(cls, SparseBitVect, int) -> Any: ...
    @classmethod
    def __invert__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...
    @classmethod
    def __xor__(cls, other) -> Any: ...

class UIntSparseIntVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetLength(cls, RDKit) -> Any: ...
    @classmethod
    def GetNonzeroElements(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalVal(cls, RDKit) -> Any: ...
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @classmethod
    def ToList(cls, RDKit) -> Any: ...
    @classmethod
    def UpdateFromSequence(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedint) -> Any: ...
    def __iadd__(self, RDKit) -> Any: ...
    @classmethod
    def __idiv__(cls, boost, int) -> Any: ...
    @classmethod
    def __imul__(cls, boost, int) -> Any: ...
    def __isub__(self, RDKit) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, RDKit, unsignedint, int) -> Any: ...
    @classmethod
    def __sub__(cls, other) -> Any: ...

class ULongSparseIntVect:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetLength(cls, RDKit) -> Any: ...
    @classmethod
    def GetNonzeroElements(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalVal(cls, RDKit) -> Any: ...
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @classmethod
    def ToList(cls, RDKit) -> Any: ...
    @classmethod
    def UpdateFromSequence(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __add__(cls, other) -> Any: ...
    @classmethod
    def __and__(cls, other) -> Any: ...
    @classmethod
    def __eq__(cls, other) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedlong) -> Any: ...
    def __iadd__(self, RDKit) -> Any: ...
    @classmethod
    def __idiv__(cls, boost, int) -> Any: ...
    @classmethod
    def __imul__(cls, boost, int) -> Any: ...
    def __isub__(self, RDKit) -> Any: ...
    @classmethod
    def __ne__(cls, other) -> Any: ...
    @classmethod
    def __or__(cls, other) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, RDKit, unsignedlong, int) -> Any: ...
    @classmethod
    def __sub__(cls, other) -> Any: ...

def AllBitSimilarity(*args, **kwargs) -> Any: ...
def AllProbeBitsMatch(*args, **kwargs) -> Any: ...
def AsymmetricSimilarity(*args, **kwargs) -> Any: ...
def AsymmetricSimilarityNeighbors(*args, **kwargs) -> Any: ...
def AsymmetricSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
@overload
def BitVectToBinaryText(SparseBitVect) -> Any: ...
@overload
def BitVectToBinaryText(ExplicitBitVect) -> Any: ...
@overload
def BitVectToFPSText(SparseBitVect) -> Any: ...
@overload
def BitVectToFPSText(ExplicitBitVect) -> Any: ...
@overload
def BitVectToText(SparseBitVect) -> Any: ...
@overload
def BitVectToText(ExplicitBitVect) -> Any: ...
def BraunBlanquetSimilarity(*args, **kwargs) -> Any: ...
def BraunBlanquetSimilarityNeighbors(*args, **kwargs) -> Any: ...
def BraunBlanquetSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def BulkAllBitSimilarity(*args, **kwargs) -> Any: ...
def BulkAsymmetricSimilarity(*args, **kwargs) -> Any: ...
def BulkBraunBlanquetSimilarity(*args, **kwargs) -> Any: ...
def BulkCosineSimilarity(*args, **kwargs) -> Any: ...
def BulkDiceSimilarity(RDKit, boost) -> Any: ...
def BulkKulczynskiSimilarity(*args, **kwargs) -> Any: ...
def BulkMcConnaugheySimilarity(*args, **kwargs) -> Any: ...
def BulkOnBitSimilarity(*args, **kwargs) -> Any: ...
def BulkRogotGoldbergSimilarity(*args, **kwargs) -> Any: ...
def BulkRusselSimilarity(*args, **kwargs) -> Any: ...
def BulkSokalSimilarity(*args, **kwargs) -> Any: ...
def BulkTanimotoSimilarity(RDKit, boost) -> Any: ...
def BulkTverskySimilarity(*args, **kwargs) -> Any: ...
def ComputeL1Norm(*args, **kwargs) -> Any: ...
def ConvertToExplicit(*args, **kwargs) -> Any: ...
@overload
def ConvertToNumpyArray(ExplicitBitVect, boost) -> Any: ...
@overload
def ConvertToNumpyArray(RDKit, boost) -> Any: ...
def CosineSimilarity(*args, **kwargs) -> Any: ...
def CosineSimilarityNeighbors(*args, **kwargs) -> Any: ...
def CosineSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def CreateFromBinaryText(*args, **kwargs) -> Any: ...
def CreateFromBitString(*args, **kwargs) -> Any: ...
def CreateFromFPSText(*args, **kwargs) -> Any: ...
def DiceSimilarity(*args, **kwargs) -> Any: ...
def DiceSimilarityNeighbors(*args, **kwargs) -> Any: ...
def DiceSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def FoldFingerprint(*args, **kwargs) -> Any: ...
def InitFromDaylightString(*args, **kwargs) -> Any: ...
def KulczynskiSimilarity(*args, **kwargs) -> Any: ...
def KulczynskiSimilarityNeighbors(*args, **kwargs) -> Any: ...
def KulczynskiSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def McConnaugheySimilarity(*args, **kwargs) -> Any: ...
def McConnaugheySimilarityNeighbors(*args, **kwargs) -> Any: ...
def McConnaugheySimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def NumBitsInCommon(*args, **kwargs) -> Any: ...
def OffBitProjSimilarity(*args, **kwargs) -> Any: ...
def OffBitsInCommon(*args, **kwargs) -> Any: ...
def OnBitProjSimilarity(*args, **kwargs) -> Any: ...
def OnBitSimilarity(*args, **kwargs) -> Any: ...
def OnBitsInCommon(*args, **kwargs) -> Any: ...
def RogotGoldbergSimilarity(*args, **kwargs) -> Any: ...
def RogotGoldbergSimilarityNeighbors(*args, **kwargs) -> Any: ...
def RogotGoldbergSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def RusselSimilarity(*args, **kwargs) -> Any: ...
def RusselSimilarityNeighbors(*args, **kwargs) -> Any: ...
def RusselSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def SokalSimilarity(*args, **kwargs) -> Any: ...
def SokalSimilarityNeighbors(*args, **kwargs) -> Any: ...
def SokalSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def TanimotoSimilarity(*args, **kwargs) -> Any: ...
def TanimotoSimilarityNeighbors(*args, **kwargs) -> Any: ...
def TanimotoSimilarityNeighbors_sparse(*args, **kwargs) -> Any: ...
def TverskySimilarity(*args, **kwargs) -> Any: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem, Geometry as Geometry
from rdkit.Chem import rdDepictor as rdDepictor

def AlignMolToTemplate2D(
    mol,
    template,
    match: Incomplete | None = ...,
    clearConfs: bool = ...,
    templateConfId: int = ...,
): ...
def _test(): ...



from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig
from rdkit.Dbase import DbModule as DbModule
from rdkit.Dbase.DbConnection import DbConnect as DbConnect

def SetDefaults(runDetails): ...

class CompositeRun:
    fields: Incomplete
    def _CreateTable(self, cn, tblName): ...
    def Store(
        self, db: str = ..., table: str = ..., user: str = ..., password: str = ...
    ) -> None: ...
    def GetDataSet(self, **kwargs): ...
    def GetDataSetInfo(self, **kwargs): ...



from _typeshed import Incomplete
from collections.abc import Generator
from rdkit import Chem as Chem
from rdkit.Chem import AllChem as AllChem, Crippen as Crippen
from rdkit.Chem.ChemUtils.AlignDepict import AlignDepict as AlignDepict

logger: Incomplete
_version: str
_greet: Incomplete
_usage: str

def Usage() -> None: ...

nDumped: int

def _exploder(
    mol,
    depth,
    sidechains,
    core,
    chainIndices,
    autoNames: bool = ...,
    templateName: str = ...,
    resetCounter: bool = ...,
    do3D: bool = ...,
    useTethers: bool = ...,
) -> Generator[Incomplete, None, None]: ...
def Explode(
    template,
    sidechains,
    outF,
    autoNames: bool = ...,
    do3D: bool = ...,
    useTethers: bool = ...,
) -> None: ...
def MoveDummyNeighborsToBeginning(mol, useAll: bool = ...): ...
def ConstructSidechains(
    suppl, sma: Incomplete | None = ..., replace: bool = ..., useAll: bool = ...
): ...



from _typeshed import Incomplete

vsaBins: Incomplete

def VSA_EState_(mol, bins: Incomplete | None = ..., force: int = ...): ...

estateBins: Incomplete

def EState_VSA_(mol, bins: Incomplete | None = ..., force: int = ...): ...
def _descriptorDocstring(name, nbin, bins): ...
def _descriptor_VSA_EState(nbin): ...
def _descriptor_EState_VSA(nbin): ...
def _InstallDescriptors() -> None: ...



from _typeshed import Incomplete

class MolSupplier:
    def __init__(self) -> None: ...
    def Reset(self) -> None: ...
    def __iter__(self): ...
    def next(self): ...
    def NextMol(self) -> None: ...
    __next__: Incomplete



from _typeshed import Incomplete
from rdkit import Chem as Chem, DataStructs as DataStructs
from rdkit.Chem.Fingerprints import (
    DbFpSupplier as DbFpSupplier,
    FingerprintMols as FingerprintMols,
)
from rdkit.DataStructs.TopNContainer import TopNContainer as TopNContainer
from rdkit.Dbase import DbModule as DbModule
from rdkit.Dbase.DbConnection import DbConnect as DbConnect

def _ConnectToDatabase(details) -> DbConnect: ...
def _ConstructSQL(details, extraFields: str = ...): ...
def ScreenInDb(details, mol): ...
def GetFingerprints(details): ...
def ScreenFingerprints(
    details, data, mol: Incomplete | None = ..., probeFp: Incomplete | None = ...
): ...
def ScreenFromDetails(details, mol: Incomplete | None = ...): ...

_usageDoc: str



from _typeshed import Incomplete
from rdkit.Dbase.DbConnection import DbConnect as DbConnect
from rdkit.ML import (
    BuildComposite as BuildComposite,
    CompositeRun as CompositeRun,
    ScreenComposite as ScreenComposite,
)
from rdkit.ML.Composite import AdjustComposite as AdjustComposite
from rdkit.ML.Data import DataUtils as DataUtils, SplitData as SplitData

_runDetails: Incomplete
__VERSION_STRING: str
_verbose: int

def message(msg) -> None: ...
def GrowIt(
    details,
    composite,
    progressCallback: Incomplete | None = ...,
    saveIt: int = ...,
    setDescNames: int = ...,
    data: Incomplete | None = ...,
): ...
def GetComposites(details): ...
def BalanceComposite(
    details, composite, data1: Incomplete | None = ..., data2: Incomplete | None = ...
): ...
def ShowVersion(includeArgs: int = ...) -> None: ...
def Usage() -> None: ...
def SetDefaults(runDetails: Incomplete | None = ...): ...
def ParseArgs(runDetails) -> None: ...



from _typeshed import Incomplete
from rdkit import DataStructs as DataStructs

class VectCollection:
    __vects: Incomplete
    __orVect: Incomplete
    __numBits: int
    __needReset: bool
    def __init__(self) -> None: ...
    def GetOrVect(self): ...
    orVect: Incomplete
    def AddVect(self, idx, vect) -> None: ...
    def Reset(self) -> None: ...
    def NumChildren(self): ...
    def GetChildren(self): ...
    def __getitem__(self, idx): ...
    GetBit: Incomplete
    def __len__(self) -> int: ...
    GetNumBits: Incomplete
    def GetOnBits(self): ...
    def DetachVectsNotMatchingBit(self, bit) -> None: ...
    def DetachVectsMatchingBit(self, bit) -> None: ...
    __needsReset: bool
    def Uniquify(self, verbose: bool = ...) -> None: ...
    def __getstate__(self): ...
    def __setstate__(self, pkl) -> None: ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from rdkit import Chem as Chem
from rdkit.Chem import Randomize as Randomize

def TestMolecule(mol): ...
def TestSupplier(
    suppl,
    stopAfter: int = ...,
    reportInterval: int = ...,
    reportTo=...,
    nameProp: str = ...,
): ...



from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig
from rdkit.ML.Descriptors import Descriptors as Descriptors, Parser as Parser
from rdkit.utils import chemutils as chemutils

countOptions: Incomplete

def GetAllDescriptorNames(db, tbl1, tbl2, user: str = ..., password: str = ...): ...

class CompoundDescriptorCalculator(Descriptors.DescriptorCalculator):
    def SUM(self, desc, compos): ...
    def MEAN(self, desc, compos): ...
    def DEV(self, desc, compos): ...
    def MIN(self, desc, compos): ...
    def MAX(self, desc, compos): ...
    nonZeroDescriptors: Incomplete
    requiredDescriptors: Incomplete
    def ProcessSimpleList(self): ...
    def ProcessCompoundList(self) -> None: ...
    atomDict: Incomplete
    def BuildAtomDict(self) -> None: ...
    def CalcSimpleDescriptorsForComposition(
        self, compos: str = ..., composList: Incomplete | None = ...
    ): ...
    def CalcCompoundDescriptorsForComposition(
        self, compos: str = ..., composList: Incomplete | None = ..., propDict=...
    ): ...
    def CalcDescriptorsForComposition(self, composVect, propDict): ...
    CalcDescriptors: Incomplete
    descriptorNames: Incomplete
    def GetDescriptorNames(self): ...
    simpleList: Incomplete
    compoundList: Incomplete
    dbName: Incomplete
    dbTable: Incomplete
    dbUser: Incomplete
    dbPassword: Incomplete
    def __init__(
        self,
        simpleList,
        compoundList: Incomplete | None = ...,
        dbName: Incomplete | None = ...,
        dbTable: str = ...,
        dbUser: str = ...,
        dbPassword: str = ...,
    ) -> None: ...

def _exampleCode() -> None: ...



from _typeshed import Incomplete
from rdkit import rdBase as rdBase
from rdkit.DataStructs import cDataStructs as cDataStructs

similarityFunctions: Incomplete

def FingerprintSimilarity(fp1, fp2, metric=...): ...
def FoldToTargetDensity(fp, density: float = ..., minLength: int = ...): ...



from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

def ExplainAtomCode(code, branchSubtract: int = ..., includeChirality: bool = ...): ...

GetAtomCode: Incomplete

def NumPiElectrons(atom): ...
def BitsInCommon(v1, v2): ...
def DiceSimilarity(v1, v2, bounds: Incomplete | None = ...): ...
def Dot(v1, v2): ...
def CosineSimilarity(v1, v2): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete

class SkeletonPoint:
    location: Incomplete
    shapeMoments: Incomplete
    shapeDirs: Incomplete
    molFeatures: Incomplete
    featmapFeatures: Incomplete
    fracVol: float
    def __init__(self, *args, **kwargs) -> None: ...
    def _initMemberData(self) -> None: ...

class ShapeWithSkeleton:
    grid: Incomplete
    skelPts: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def _initMemberData(self) -> None: ...

class SubshapeShape:
    shapes: Incomplete
    featMap: Incomplete
    keyFeat: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def _initMemberData(self) -> None: ...

def _displaySubshapeSkelPt(viewer, skelPt, cgoNm, color) -> None: ...
def DisplaySubshapeSkeleton(
    viewer, shape, name, color=..., colorByOrder: bool = ...
) -> None: ...
def DisplaySubshape(
    viewer, shape, name, showSkelPts: bool = ..., color=...
) -> None: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.VLib.Output import OutputNode as BaseOutputNode

class OutputNode(BaseOutputNode):
    _dest: Incomplete
    _idField: Incomplete
    _delim: Incomplete
    _nDumped: int
    def __init__(
        self,
        dest: Incomplete | None = ...,
        delim: str = ...,
        idField: Incomplete | None = ...,
        **kwargs
    ) -> None: ...
    def reset(self) -> None: ...
    def smilesOut(self, mol): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem, RDConfig as RDConfig

class FGHierarchyNode:
    children: Incomplete
    name: str
    label: str
    pattern: Incomplete
    smarts: str
    rxnSmarts: str
    parent: Incomplete
    removalReaction: Incomplete
    def __init__(
        self,
        name,
        patt,
        smarts: str = ...,
        label: str = ...,
        rxnSmarts: str = ...,
        parent: Incomplete | None = ...,
    ) -> None: ...
    def __len__(self) -> int: ...

class FuncGroupFileParseError(ValueError): ...

groupDefns: Incomplete
hierarchy: Incomplete
lastData: Incomplete
lastFilename: Incomplete

def BuildFuncGroupHierarchy(
    fileNm: Incomplete | None = ..., data: Incomplete | None = ..., force: bool = ...
): ...
def _SetNodeBits(mol, node, res, idx): ...
def CreateMolFingerprint(mol, hierarchy): ...



from _typeshed import Incomplete
from rdkit.ML.Data import SplitData as SplitData
from rdkit.ML.DecTree import ID3 as ID3, randomtest as randomtest

def ChooseOptimalRoot(
    examples,
    trainExamples,
    testExamples,
    attrs,
    nPossibleVals,
    treeBuilder,
    nQuantBounds=...,
    **kwargs
): ...
def CrossValidate(tree, testExamples, appendExamples: int = ...): ...
def CrossValidationDriver(
    examples,
    attrs,
    nPossibleVals,
    holdOutFrac: float = ...,
    silent: int = ...,
    calcTotalError: int = ...,
    treeBuilder=...,
    lessGreedy: int = ...,
    startAt: Incomplete | None = ...,
    nQuantBounds=...,
    maxDepth: int = ...,
    **kwargs
): ...
def TestRun() -> None: ...



from _typeshed import Incomplete

class ChemdrawPanel:
    cdx: Incomplete
    offset: int
    label: Incomplete
    def __init__(
        self,
        parent: Incomplete | None = ...,
        name: str = ...,
        readOnly: int = ...,
        size=...,
    ) -> None: ...
    def pullData(self, fmt: str = ...): ...
    def setData(self, data, fmt: str = ...): ...
    def resizeEvent(self, evt) -> None: ...
    def __del__(self) -> None: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import AllChem as AllChem

murckoTransforms: Incomplete

def MakeScaffoldGeneric(mol): ...

murckoPatts: Incomplete
murckoQ: Incomplete
aromaticNTransform: Incomplete

def GetScaffoldForMol(mol): ...
def _pyGetScaffoldForMol(mol): ...
def MurckoScaffoldSmiles(
    smiles: Incomplete | None = ...,
    mol: Incomplete | None = ...,
    includeChirality: bool = ...,
): ...
def MurckoScaffoldSmilesFromSmiles(smiles, includeChirality: bool = ...): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from typing import Optional
from rdkit import Chem
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

def PMI1(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    First (smallest) principal moment of inertia

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def PMI2(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Second principal moment of inertia

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def PMI3(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Third (largest) principal moment of inertia

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def NPR1(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Normalized principal moments ratio 1 (=I1/I3)

        from Sauer and Schwarz JCIM 43:987-1003 (2003)
        https://doi.org/10.1021/ci025599w


    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def NPR2(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Normalized principal moments ratio 2 (=I2/I3)

        from Sauer and Schwarz JCIM 43:987-1003 (2003)
        https://doi.org/10.1021/ci025599w


    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def RadiusOfGyration(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Radius of gyration

        from Todeschini and Consoni "Descriptors from Molecular Geometry"
        Handbook of Chemoinformatics
        https://doi.org/10.1002/9783527618279.ch37

        Definition:
          for planar molecules: sqrt( sqrt(pm3*pm2)/MW )
          for nonplanar molecules: sqrt( 2*pi*pow(pm3*pm2*pm1,1/3)/MW )

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def InertialShapeFactor(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    Inertial shape factor

        from Todeschini and Consoni "Descriptors from Molecular Geometry"
        Handbook of Chemoinformatics
        https://doi.org/10.1002/9783527618279.ch37

        Definition:
          pm2 / (pm1*pm3)

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def Eccentricity(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    molecular eccentricity

        from Todeschini and Consoni "Descriptors from Molecular Geometry"
        Handbook of Chemoinformatics
        https://doi.org/10.1002/9783527618279.ch37

        Definition:
          sqrt(pm3**2 -pm1**2) / pm3

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def Asphericity(
    mol: Chem.Mol, confId: int = -1, useAtomicMasses: bool = True, force: bool = True
) -> float:
    """
    molecular asphericity

        from Todeschini and Consoni "Descriptors from Molecular Geometry"
        Handbook of Chemoinformatics
        https://doi.org/10.1002/9783527618279.ch37

        Definition:
          0.5 * ((pm3-pm2)**2 + (pm3-pm1)**2 + (pm2-pm1)**2)/(pm1**2+pm2**2+pm3**2)

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

      - useAtomicMasses: (optional) toggles use of atomic masses in the
        calculation. Defaults to True
    """

def SpherocityIndex(mol: Chem.Mol, confId: int = -1, force: bool = True) -> float:
    """
    Molecular spherocityIndex

        from Todeschini and Consoni "Descriptors from Molecular Geometry"
        Handbook of Chemoinformatics
        https://doi.org/10.1002/9783527618279.ch37

        Definition:
          3 * pm1 / (pm1+pm2+pm3) where the moments are calculated without weights

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

    """

def PBF(mol: Chem.Mol, confId: int = -1) -> float:
    """
    Plane of best fit
      from: https://doi.org/10.1021/ci300293f

    **Arguments**

      - inMol: a molecule

      - confId: (optional) the conformation ID to use

    """

def CalcMolDescriptors3D(mol: Chem.Mol, confId: Optional[int] = None):
    """
    Compute all 3D descriptors of a molecule

    Arguments:
    - mol: the molecule to work with
    - confId: conformer ID to work with. If not specified the default (-1) is used

    Return:

    dict
        A dictionary with decriptor names as keys and the descriptor values as values

    raises a ValueError
        If the molecule does not have conformers
    """



from _typeshed import Incomplete
from rdkit.Dbase import DbInfo as DbInfo

class DbResultBase:
    cursor: Incomplete
    removeDups: Incomplete
    transform: Incomplete
    cmd: Incomplete
    conn: Incomplete
    extras: Incomplete
    def __init__(
        self,
        cursor,
        conn,
        cmd,
        removeDups: int = ...,
        transform: Incomplete | None = ...,
        extras: Incomplete | None = ...,
    ) -> None: ...
    def Reset(self) -> None: ...
    def __iter__(self): ...
    colNames: Incomplete
    colTypes: Incomplete
    def _initColumnNamesAndTypes(self) -> None: ...
    def GetColumnNames(self): ...
    def GetColumnTypes(self): ...
    def GetColumnNamesAndTypes(self): ...

class DbResultSet(DbResultBase):
    seen: Incomplete
    _stopped: int
    def __init__(self, *args, **kwargs) -> None: ...
    def Reset(self) -> None: ...
    def next(self): ...
    __next__: Incomplete

class RandomAccessDbResultSet(DbResultBase):
    results: Incomplete
    seen: Incomplete
    _pos: int
    def __init__(self, *args, **kwargs) -> None: ...
    def Reset(self) -> None: ...
    cursor: Incomplete
    def _finish(self) -> None: ...
    def __getitem__(self, idx): ...
    def __len__(self) -> int: ...
    def next(self): ...
    __next__: Incomplete



from typing import Any, ClassVar

class FragCatGenerator:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddFragsFromMol(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class FragCatParams:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetFuncGroup(cls, RDKit, int) -> Any: ...
    @classmethod
    def GetLowerFragLength(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumFuncGroups(cls, RDKit) -> Any: ...
    @classmethod
    def GetTolerance(cls, RDKit) -> Any: ...
    @classmethod
    def GetTypeString(cls, RDKit) -> Any: ...
    @classmethod
    def GetUpperFragLength(cls, RDKit) -> Any: ...
    @classmethod
    def Serialize(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class FragCatalog:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetBitDescription(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBitDiscrims(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBitEntryId(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBitFuncGroupIds(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBitOrder(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetCatalogParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEntryBitId(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEntryDescription(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEntryDownIds(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEntryFuncGroupIds(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEntryOrder(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetFPLength(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetNumEntries(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Serialize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __getinitargs__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class FragFPGenerator:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetFPForMol(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import Crippen as Crippen, MolSurf as MolSurf
from rdkit.Chem.ChemUtils.DescriptorUtilities import (
    setDescriptorVersion as setDescriptorVersion,
)
from typing import NamedTuple

class QEDproperties(NamedTuple):
    MW: Incomplete
    ALOGP: Incomplete
    HBA: Incomplete
    HBD: Incomplete
    PSA: Incomplete
    ROTB: Incomplete
    AROM: Incomplete
    ALERTS: Incomplete

class ADSparameter(NamedTuple):
    A: Incomplete
    B: Incomplete
    C: Incomplete
    D: Incomplete
    E: Incomplete
    F: Incomplete
    DMAX: Incomplete

WEIGHT_MAX: Incomplete
WEIGHT_MEAN: Incomplete
WEIGHT_NONE: Incomplete
AliphaticRings: Incomplete
AcceptorSmarts: Incomplete
Acceptors: Incomplete
StructuralAlertSmarts: Incomplete
StructuralAlerts: Incomplete
adsParameters: Incomplete

def ads(x, adsParameter): ...
def properties(mol): ...
def qed(mol, w=..., qedProperties: Incomplete | None = ...): ...
def weights_max(mol): ...
def weights_mean(mol): ...
def weights_none(mol): ...
def default(mol): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import rdDepictor as rdDepictor
from rdkit.Chem.Draw.MolDrawing import (
    DrawingOptions as DrawingOptions,
    MolDrawing as MolDrawing,
)
from rdkit.Dbase import DbInfo as DbInfo
from rdkit.Dbase.DbConnection import DbConnect as DbConnect
from rdkit.utils import cactvs as cactvs

GetReportlabTable: Incomplete
QuickReport: Incomplete
hasCDX: int

class CDXImageTransformer:
    smiCol: Incomplete
    tempHandler: Incomplete
    width: Incomplete
    verbose: Incomplete
    def __init__(
        self,
        smiCol,
        width: int = ...,
        verbose: int = ...,
        tempHandler: Incomplete | None = ...,
    ) -> None: ...
    def __call__(self, arg): ...

class CactvsImageTransformer:
    smiCol: Incomplete
    tempHandler: Incomplete
    width: Incomplete
    verbose: Incomplete
    def __init__(
        self,
        smiCol,
        width: float = ...,
        verbose: int = ...,
        tempHandler: Incomplete | None = ...,
    ) -> None: ...
    def __call__(self, arg): ...

class ReportLabImageTransformer:
    smiCol: Incomplete
    width: Incomplete
    verbose: Incomplete
    def __init__(
        self,
        smiCol,
        width: float = ...,
        verbose: int = ...,
        tempHandler: Incomplete | None = ...,
    ) -> None: ...
    def __call__(self, arg): ...

class RDImageTransformer:
    smiCol: Incomplete
    tempHandler: Incomplete
    width: Incomplete
    verbose: Incomplete
    def __init__(
        self,
        smiCol,
        width: float = ...,
        verbose: int = ...,
        tempHandler: Incomplete | None = ...,
    ) -> None: ...
    def __call__(self, arg): ...



from _typeshed import Incomplete
from rdkit import Chem as Chem

_server: Incomplete

class MolViewer:
    server: Incomplete
    def __init__(
        self, host: Incomplete | None = ..., port: int = ..., force: int = ..., **kwargs
    ) -> None: ...
    def InitializePyMol(self) -> None: ...
    def DeleteAll(self) -> None: ...
    def DeleteAllExcept(self, excludes) -> None: ...
    def LoadFile(self, filename, name, showOnly: bool = ...): ...
    def ShowMol(
        self,
        mol,
        name: str = ...,
        showOnly: bool = ...,
        highlightFeatures=...,
        molB: str = ...,
        confId: int = ...,
        zoom: bool = ...,
        forcePDB: bool = ...,
        showSticks: bool = ...,
    ): ...
    def GetSelectedAtoms(self, whichSelection: Incomplete | None = ...): ...
    def SelectAtoms(self, itemId, atomIndices, selName: str = ...) -> None: ...
    def HighlightAtoms(self, indices, where, extraHighlight: bool = ...) -> None: ...
    def SetDisplayStyle(self, obj, style: str = ...) -> None: ...
    def SelectProteinNeighborhood(
        self,
        aroundObj,
        inObj,
        distance: float = ...,
        name: str = ...,
        showSurface: bool = ...,
    ) -> None: ...
    def AddPharmacophore(self, locs, colors, label, sphereRad: float = ...) -> None: ...
    def SetDisplayUpdate(self, val) -> None: ...
    def GetAtomCoords(self, sels): ...
    def HideAll(self) -> None: ...
    def HideObject(self, objName) -> None: ...
    def DisplayObject(self, objName) -> None: ...
    def Redraw(self) -> None: ...
    def Zoom(self, objName) -> None: ...
    def DisplayHBonds(
        self,
        objName,
        molName,
        proteinName,
        molSelText: str = ...,
        proteinSelText: str = ...,
    ) -> None: ...
    def DisplayCollisions(
        self,
        objName,
        molName,
        proteinName,
        distCutoff: float = ...,
        color: str = ...,
        molSelText: str = ...,
        proteinSelText: str = ...,
    ) -> None: ...
    def SaveFile(self, filename) -> None: ...
    def GetPNG(
        self,
        h: Incomplete | None = ...,
        w: Incomplete | None = ...,
        preDelay: int = ...,
    ): ...



from . import ActFuncs as ActFuncs
from _typeshed import Incomplete

class NetNode:
    def Eval(self, valVect): ...
    inputNodes: Incomplete
    def SetInputs(self, inputNodes) -> None: ...
    def GetInputs(self): ...
    weights: Incomplete
    def SetWeights(self, weights) -> None: ...
    def GetWeights(self): ...
    nodeIndex: Incomplete
    nodeList: Incomplete
    actFunc: Incomplete
    def __init__(
        self,
        nodeIndex,
        nodeList,
        inputNodes: Incomplete | None = ...,
        weights: Incomplete | None = ...,
        actFunc=...,
        actFuncParms=...,
    ) -> None: ...



from _typeshed import Incomplete
from rdkit.rdBase import (
    AttachFileToLog as AttachFileToLog,
    DisableLog as DisableLog,
    EnableLog as EnableLog,
    LogMessage as LogMessage,
)

_levels: Incomplete
DEBUG: int
INFO: int
WARNING: int
ERROR: int
CRITICAL: int

class logger:
    def logIt(self, dest, msg, *args, **kwargs) -> None: ...
    def debug(self, msg, *args, **kwargs) -> None: ...
    def error(self, msg, *args, **kwargs) -> None: ...
    def info(self, msg, *args, **kwargs) -> None: ...
    def warning(self, msg, *args, **kwargs) -> None: ...
    def critical(self, msg, *args, **kwargs) -> None: ...
    def setLevel(self, val) -> None: ...



def GetNodeList(cluster): ...
def GetNodesDownToCentroids(cluster, above: int = ...): ...
def FindClusterCentroidFromDists(cluster, dists): ...
def _BreadthFirstSplit(cluster, n): ...
def _HeightFirstSplit(cluster, n): ...
def SplitIntoNClusters(cluster, n, breadthFirst: bool = ...): ...



from _typeshed import Incomplete
from collections.abc import Callable
from typing import Any, Optional
from rdkit import Chem as Chem
from rdkit.Chem import (
    rdMolDescriptors as rdMolDescriptors,
    rdPartialCharges as rdPartialCharges,
)
from rdkit.Chem.EState.EState import (
    MaxAbsEStateIndex as MaxAbsEStateIndex,
    MaxEStateIndex as MaxEStateIndex,
    MinAbsEStateIndex as MinAbsEStateIndex,
    MinEStateIndex as MinEStateIndex,
)
from rdkit.Chem.QED import qed as qed

def _isCallable(thing): ...

_descList: Incomplete

def _setupDescriptors(namespace) -> None: ...

MolWt: Callable[[Chem.Mol], float]
"""
The average molecular weight of the molecule

>>> MolWt(Chem.MolFromSmiles('CC'))
30.07
>>> MolWt(Chem.MolFromSmiles('[NH4+].[Cl-]'))
53.49...
"""

def HeavyAtomMolWt(x: Chem.Mol) -> float:
    """The average molecular weight of the molecule ignoring hydrogens

    >>> HeavyAtomMolWt(Chem.MolFromSmiles('CC'))
    24.02...
    >>> HeavyAtomMolWt(Chem.MolFromSmiles('[NH4+].[Cl-]'))
    49.46

    """

ExactMolWt: Callable[[Chem.Mol], float]
"""
The exact molecular weight of the molecule

>>> ExactMolWt(Chem.MolFromSmiles('CC'))
30.04...
>>> ExactMolWt(Chem.MolFromSmiles('[13CH3]C'))
31.05...
"""

def NumValenceElectrons(mol: Chem.Mol) -> int:
    """
    The number of valence electrons the molecule has

    >>> NumValenceElectrons(Chem.MolFromSmiles('CC'))
    14
    >>> NumValenceElectrons(Chem.MolFromSmiles('C(=O)O'))
    18
    >>> NumValenceElectrons(Chem.MolFromSmiles('C(=O)[O-]'))
    18
    >>> NumValenceElectrons(Chem.MolFromSmiles('C(=O)'))
    12
    """

def NumRadicalElectrons(mol: Chem.Mol) -> int:
    """
    The number of radical electrons the molecule has
    (says nothing about spin state)

    >>> NumRadicalElectrons(Chem.MolFromSmiles('CC'))
    0
    >>> NumRadicalElectrons(Chem.MolFromSmiles('C[CH3]'))
    0
    >>> NumRadicalElectrons(Chem.MolFromSmiles('C[CH2]'))
    1
    >>> NumRadicalElectrons(Chem.MolFromSmiles('C[CH]'))
    2
    >>> NumRadicalElectrons(Chem.MolFromSmiles('C[C]'))
    3
    """

def _ChargeDescriptors(mol: Chem.Mol, force: bool = False) -> tuple[float, float]: ...
def MaxPartialCharge(mol: Chem.Mol, force: bool = False) -> float: ...
def MinPartialCharge(mol: Chem.Mol, force: bool = False) -> float: ...
def MaxAbsPartialCharge(mol: Chem.Mol, force: bool = False) -> float: ...
def MinAbsPartialCharge(mol: Chem.Mol, force: bool = False) -> float: ...
def _FingerprintDensity(mol: Chem.Mol, func, *args, **kwargs) -> float: ...
def FpDensityMorgan1(x) -> float: ...
def FpDensityMorgan2(x) -> float: ...
def FpDensityMorgan3(x) -> float: ...
def setupAUTOCorrDescriptors() -> None:
    """Adds AUTOCORR descriptors to the default descriptor lists"""

class PropertyFunctor(rdMolDescriptors.PythonPropertyFunctor):
    """
    Creates a python based property function that can be added to the
    global property list.  To use, subclass this class and override the
    __call__ method.  Then create an instance and add it to the
    registry.  The __call__ method should return a numeric value.

    Example:

        class NumAtoms(Descriptors.PropertyFunctor):
            def __init__(self):
                Descriptors.PropertyFunctor.__init__(self, "NumAtoms", "1.0.0")
            def __call__(self, mol):
                return mol.GetNumAtoms()

        numAtoms = NumAtoms()
        rdMolDescriptors.Properties.RegisterProperty(numAtoms)
    """

    def __init__(self, name, version) -> None: ...
    def __call__(self, mol) -> Any: ...

def CalcMolDescriptors(
    mol: Chem.Mol, missingVal: Optional[float] = None, silent: bool = True
) -> dict[str, float | int]:
    """
    calculate the full set of descriptors for a molecule

    Parameters
    ----------
    mol : RDKit molecule
    missingVal : float, optional
                 This will be used if a particular descriptor cannot be calculated
    silent : bool, optional
             if True then exception messages from descriptors will be displayed

    Returns
    -------
    dict
         A dictionary with decriptor names as keys and the descriptor values as values
    """

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...



from _typeshed import Incomplete

class ReFile:
    def readline(self): ...
    def readlines(self): ...
    def rewind(self) -> None: ...
    regExp: Incomplete
    inFile: Incomplete
    def __init__(
        self, fileName, mode: str = ..., comment: str = ..., trailer: str = ...
    ) -> None: ...

def ReadDataFile(fileName, comment: str = ..., depVarCol: int = ..., dataType=...): ...
